@@ -8,8 +8,8 @@ def create_file_chunks(bucket_name, file_pattern, job_uuid, file_headers, integr
     import os
     import csv
     from datetime import datetime
-    from stratus_api.integrations.utils.cache import cache_data
-    from stratus_api.integrations.utils.cache import get_cached_data
+    from stratus_api.integrations.cache import cache_data
+    from stratus_api.integrations.cache import get_cached_data
 
     chunk_number = 0
     chunk_records = 0
