@@ -5,7 +5,8 @@ def create_destination_request(user, token_info, body):
         external_id, external_attributes = create_entity(
             entity_type='destination', name=body['name'],
             platform_name=body['platform_name'],
-            destination_uuid=body['destination_uuid'], settings=body['settings']
+            destination_uuid=body['destination_uuid'], settings=body['settings'],
+            token_info=token_info
         )
     except ApiError as e:
         return dict(status=400, title='Bad Request', detail=e.args[0], type='about:blank'), 400
